==> cdktf-cdktf-provider-google-0.6.11.tar.gz: package/lib/data-google-cloudfunctions-function.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataGoogleCloudfunctionsFunctionConfig extends cdktf.TerraformMetaArguments {
    /**
     * A user-defined name of the function. Function names must be unique globally.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/cloudfunctions_function#name DataGoogleCloudfunctionsFunction#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Project of the function. If it is not provided, the provider project is used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/cloudfunctions_function#project DataGoogleCloudfunctionsFunction#project}
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * Region of function. If it is not provided, the provider region is used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/cloudfunctions_function#region DataGoogleCloudfunctionsFunction#region}
     *
     * @stability stable
     */
    readonly region?: string;
}
/**
 * @stability stable
 */
export declare class DataGoogleCloudfunctionsFunctionEventTriggerFailurePolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get retry(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataGoogleCloudfunctionsFunctionEventTrigger extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get eventType(): string;
    /**
     * @stability stable
     */
    get failurePolicy(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get resource(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleCloudfunctionsFunctionSourceRepository extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get deployedUrl(): string;
    /**
     * @stability stable
     */
    get url(): string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/d/cloudfunctions_function google_cloudfunctions_function}.
 *
 * @stability stable
 */
export declare class DataGoogleCloudfunctionsFunction extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/d/cloudfunctions_function google_cloudfunctions_function} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataGoogleCloudfunctionsFunctionConfig);
    /**
     * @stability stable
     */
    get availableMemoryMb(): number;
    /**
     * @stability stable
     */
    buildEnvironmentVariables(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    get entryPoint(): string;
    /**
     * @stability stable
     */
    environmentVariables(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    eventTrigger(index: string): DataGoogleCloudfunctionsFunctionEventTrigger;
    /**
     * @stability stable
     */
    get httpsTriggerUrl(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get ingressSettings(): string;
    /**
     * @stability stable
     */
    labels(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    get maxInstances(): number;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    /**
     * @stability stable
     */
    get runtime(): string;
    /**
     * @stability stable
     */
    get serviceAccountEmail(): string;
    /**
     * @stability stable
     */
    get sourceArchiveBucket(): string;
    /**
     * @stability stable
     */
    get sourceArchiveObject(): string;
    /**
     * @stability stable
     */
    sourceRepository(index: string): DataGoogleCloudfunctionsFunctionSourceRepository;
    /**
     * @stability stable
     */
    get timeout(): number;
    /**
     * @stability stable
     */
    get triggerHttp(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get vpcConnector(): string;
    /**
     * @stability stable
     */
    get vpcConnectorEgressSettings(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-0.6.38.tar.gz: package/lib/data-google-cloudfunctions-function.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleCloudfunctionsFunctionConfig extends cdktf.TerraformMetaArguments {
    /**
    * A user-defined name of the function. Function names must be unique globally.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/cloudfunctions_function#name DataGoogleCloudfunctionsFunction#name}
    */
    readonly name: string;
    /**
    * Project of the function. If it is not provided, the provider project is used.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/cloudfunctions_function#project DataGoogleCloudfunctionsFunction#project}
    */
    readonly project?: string;
    /**
    * Region of function. If it is not provided, the provider region is used.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/cloudfunctions_function#region DataGoogleCloudfunctionsFunction#region}
    */
    readonly region?: string;
}
export declare class DataGoogleCloudfunctionsFunctionEventTriggerFailurePolicy extends cdktf.ComplexComputedList {
    get retry(): cdktf.IResolvable;
}
export declare class DataGoogleCloudfunctionsFunctionEventTrigger extends cdktf.ComplexComputedList {
    get eventType(): string;
    get failurePolicy(): cdktf.IResolvable;
    get resource(): string;
}
export declare class DataGoogleCloudfunctionsFunctionSourceRepository extends cdktf.ComplexComputedList {
    get deployedUrl(): string;
    get url(): string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google/d/cloudfunctions_function google_cloudfunctions_function}
*/
export declare class DataGoogleCloudfunctionsFunction extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google/d/cloudfunctions_function google_cloudfunctions_function} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleCloudfunctionsFunctionConfig
    */
    constructor(scope: Construct, id: string, config: DataGoogleCloudfunctionsFunctionConfig);
    get availableMemoryMb(): number;
    buildEnvironmentVariables(key: string): string | cdktf.IResolvable;
    get description(): string;
    get entryPoint(): string;
    environmentVariables(key: string): string | cdktf.IResolvable;
    eventTrigger(index: string): DataGoogleCloudfunctionsFunctionEventTrigger;
    get httpsTriggerUrl(): string;
    get id(): string;
    get ingressSettings(): string;
    labels(key: string): string | cdktf.IResolvable;
    get maxInstances(): number;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    get runtime(): string;
    get serviceAccountEmail(): string;
    get sourceArchiveBucket(): string;
    get sourceArchiveObject(): string;
    sourceRepository(index: string): DataGoogleCloudfunctionsFunctionSourceRepository;
    get timeout(): number;
    get triggerHttp(): cdktf.IResolvable;
    get vpcConnector(): string;
    get vpcConnectorEgressSettings(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
